==> 1.1.0.tar.gz: lib/src/cruiser_page_route.dart <==
import 'package:cruiser/cruiser.dart';
import 'package:cruiser/src/models/cruiser_transition.dart';
import 'package:cruiser/src/transitions/accordion_transition.dart';
import 'package:cruiser/src/transitions/background_to_foreground_transition.dart';
import 'package:cruiser/src/transitions/cube_transition.dart';
import 'package:cruiser/src/transitions/depth_transition.dart';
import 'package:cruiser/src/transitions/flip_horizontal_transition.dart';
import 'package:cruiser/src/transitions/flip_vertical_transition.dart';
import 'package:cruiser/src/transitions/foreground_to_background_transition.dart';
import 'package:cruiser/src/transitions/parallax_transition.dart';
import 'package:cruiser/src/transitions/rotate_down_transition.dart';
import 'package:cruiser/src/transitions/rotate_up_transition.dart';
import 'package:cruiser/src/transitions/stack_transition.dart';
import 'package:cruiser/src/transitions/tablet_transition.dart';
import 'package:cruiser/src/transitions/zoom_in_transition.dart';
import 'package:cruiser/src/transitions/zoom_out_slide_transition.dart';
import 'package:flutter/material.dart';

class CruiserPageRoute extends PageRouteBuilder 
{
    final TransitionType transition;
    final Widget exitPage;

    CruiserPageRoute({
        @required RouteSettings settings,
        @required this.transition,
        @required WidgetBuilder builder,
        Duration transitionDuration = const Duration(milliseconds: 500),
        bool opaque = true,
        bool barrierDismissible = false,
        Color barrierColor,
        String barrierLabel,
        bool maintainState = true,
        bool fullscreenDialog = false,
        this.exitPage,
    }) : super(
        settings: settings,
        pageBuilder: (context, anim1, anim2) => builder(context),
        transitionDuration: transitionDuration,
        opaque: opaque,
        barrierDismissible: barrierDismissible,
        barrierColor: barrierColor,
        barrierLabel: barrierLabel,
        maintainState: maintainState,
        fullscreenDialog: fullscreenDialog,
    );

    static CruiserTransition _getTransition(TransitionType type)
    {
        switch(type)
        {
            case TransitionType.cube: return CubeTransition();
            case TransitionType.zoomIn: return ZoomInTransition();
            case TransitionType.accordion: return AccordionTransition();
            case TransitionType.backgroundToForeground: return BackgroundToForegroundTransition();
            case TransitionType.flipHorizontal: return FlipHorizontalTransition();
            case TransitionType.flipVertical: return FlipVerticalTransition();
            case TransitionType.foregroundToBackground: return ForegroundToBackgroundTransition();
            case TransitionType.parallax: return ParallaxTransition();
            case TransitionType.rotateDown: return RotateDownTransition();
            case TransitionType.rotateUp: return RotateUpTransition();
            case TransitionType.stack: return StackTransition();
            case TransitionType.tablet: return TabletTransition();
            case TransitionType.zoomOutSlide: return ZoomOutSlideTransition();
            case TransitionType.depth: return DepthTransition();

            default: throw new Exception('$type transition not found');
        }
    }

    @override
    Widget buildTransitions(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) 
    {
        var cruiserTransition = _getTransition(transition);

        return cruiserTransition.build(context, animation, exitPage, child);
    }
}

==> 1.2.0.tar.gz: lib/src/cruiser_page_route.dart <==
import 'package:cruiser/cruiser.dart';
import 'package:cruiser/src/models/cruiser_transition.dart';
import 'package:cruiser/src/transitions/cube_transition.dart';
import 'package:cruiser/src/transitions/depth_transition.dart';
import 'package:cruiser/src/transitions/parallax_transition.dart';
import 'package:cruiser/src/transitions/tablet_transition.dart';
import 'package:flutter/material.dart';

class CruiserPageRoute extends PageRouteBuilder 
{
    final TransitionType transition;
    final Cruiser router;

    CruiserPageRoute({
        @required RouteSettings settings,
        @required this.transition,
        @required WidgetBuilder builder,
        @required this.router,
        Duration transitionDuration = const Duration(milliseconds: 600),
        bool opaque = true,
        bool barrierDismissible = false,
        Color barrierColor,
        String barrierLabel,
        bool maintainState = true,
        bool fullscreenDialog = false,
    }) : super(
        settings: settings,
        pageBuilder: (context, anim1, anim2) => builder(context),
        transitionDuration: transitionDuration,
        opaque: opaque,
        barrierDismissible: barrierDismissible,
        barrierColor: barrierColor,
        barrierLabel: barrierLabel,
        maintainState: maintainState,
        fullscreenDialog: fullscreenDialog,
    );

    @override
    Widget buildTransitions(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) 
    {
        var cruiserTransition = getTransition();

        return cruiserTransition?.build(context, animation, secondaryAnimation, child);
    }

    CruiserTransition getTransition()
    {
        switch(router.currentTransition)
        {
            case TransitionType.cube: return CubeTransition();
            case TransitionType.zoomIn: return ZoomInTransition();
            case TransitionType.accordion: return AccordionTransition();
            case TransitionType.backgroundToForeground: return BackgroundToForegroundTransition();
            case TransitionType.flipHorizontal: return FlipHorizontalTransition();
            case TransitionType.flipVertical: return FlipVerticalTransition();
            case TransitionType.foregroundToBackground: return ForegroundToBackgroundTransition();
            case TransitionType.parallax: return ParallaxTransition();
            case TransitionType.rotateDown: return RotateDownTransition();
            case TransitionType.rotateUp: return RotateUpTransition();
            case TransitionType.stack: return StackTransition();
            case TransitionType.tablet: return TabletTransition();
            case TransitionType.zoomOutSlide: return ZoomOutSlideTransition();
            case TransitionType.depth:  return DepthTransition();
            default: throw new Exception('${router.currentTransition} transition not found');
        }
    }
}
